@@ -1,14 +1,16 @@
+use 5.10.0;
 use strict;
 use warnings;
 
 package Syntax::Feature::Qi;
 
-our $VERSION = '0.2004'; # VERSION
 # ABSTRACT: Remove the same indendation from all lines in a string
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '1.0000';
 
-use Devel::Declare 0.006007 ();
-use B::Hooks::EndOfScope 0.09;
-use Sub::Install 0.925 qw/install_sub/;
+use Devel::Declare();
+use B::Hooks::EndOfScope;
+use Sub::Install qw/install_sub/;
 use Devel::Declare::Context::Simple;
 use namespace::clean;
 
@@ -98,9 +100,23 @@ __END__
 
 Syntax::Feature::Qi - Remove the same indendation from all lines in a string
 
+
+
+=begin html
+
+<p>
+<img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
+<a href="https://travis-ci.org/Csson/p5-Syntax-Feature-Qi"><img src="https://api.travis-ci.org/Csson/p5-Syntax-Feature-Qi.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Syntax-Feature-Qi-1.0000"><img src="https://badgedepot.code301.com/badge/kwalitee/Syntax-Feature-Qi/1.0000" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Syntax-Feature-Qi%201.0000"><img src="https://badgedepot.code301.com/badge/cpantesters/Syntax-Feature-Qi/1.0000" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-97.4%-yellow.svg" alt="coverage 97.4%" />
+</p>
+
+=end html
+
 =head1 VERSION
 
-Version 0.2004, released 2015-01-17.
+Version 1.0000, released 2016-04-16.
 
 =head1 SYNOPSIS
 
@@ -168,7 +184,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
